@@ -1,17 +1,8 @@
-#
-# This file is part of Redis
-#
-# This software is Copyright (c) 2015 by Pedro Melo, Damien Krotkine.
-#
-# This is free software, licensed under:
-#
-#   The Artistic License 2.0 (GPL Compatible)
-#
 package Redis::Hash;
-$Redis::Hash::VERSION = '1.990_02';
+
 # ABSTRACT: tie Perl hashes to Redis hashes
-# VERSION
-# AUTHORITY
+our $VERSION = '1.950'; # VERSION
+our $AUTHORITY = 'cpan:MELO'; # AUTHORITY
 
 use strict;
 use warnings;
@@ -47,7 +38,7 @@ sub FIRSTKEY {
 sub NEXTKEY {
   my $self = shift;
 
-  my $key = shift @{ $self->{prefix_keys} };
+  my $key = shift @{$self->{prefix_keys}};
   return unless defined $key;
 
   my $p = $self->{prefix};
@@ -72,13 +63,16 @@ sub CLEAR {
 }
 
 
-1;    ## End of Redis::Hash
+1; ## End of Redis::Hash
+
+
 
 __END__
-
 =pod
 
-=encoding UTF-8
+=for :stopwords Pedro Melo ACKNOWLEDGEMENTS
+
+=encoding utf-8
 
 =head1 NAME
 
@@ -86,14 +80,15 @@ Redis::Hash - tie Perl hashes to Redis hashes
 
 =head1 VERSION
 
-version 1.990_02
+version 1.950
 
 =head1 DESCRIPTION
 
 Ties a Perl hash to Redis. Note that it doesn't use Redis Hashes, but
 implements a fake hash using regular keys like "prefix:KEY".
 
-If no C<prefix> is given, it will tie the entire Redis database as a hash.
+If no C<prefix> is given, it will tie the entire Redis database
+as a hash.
 
 Future versions will also allow you to use real Redis hash structures.
 
@@ -101,40 +96,31 @@ Future versions will also allow you to use real Redis hash structures.
 
     ## Create fake hash using keys like 'hash_prefix:KEY'
     tie %my_hash, 'Redis::Hash', 'hash_prefix', @Redis_new_parameters;
-
+    
     ## Treat the entire Redis database as a hash
     tie %my_hash, 'Redis::Hash', undef, @Redis_new_parameters;
-
-    $value = $my_hash{$key};
-    $my_hash{$key} = $value;
-
+    
+    $value = $my_list{$key};
+    $my_list{$key} = $value;
+    
     @keys   = keys %my_hash;
     @values = values %my_hash;
-
+    
     %my_hash = reverse %my_hash;
-
+    
     %my_hash = ();
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Pedro Melo <melo@cpan.org>
 
-=item *
-
-Damien Krotkine <dams@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Pedro Melo, Damien Krotkine.
+This software is Copyright (c) 2012 by Pedro Melo.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
